==============
pytest-tesults
==============

Tesults plugin for pytest

------------


Description
------------

Tesults is the new standard in automated test results consolidation, reporting, analysis, failure tracking, manual test reporting and test case management.

Use pytest-tesults to automatically integrate with Tesults.

For complete details visit:

https://www.tesults.com/docs?doc=pytest


Requirements
------------

The Tesults Python library is required. Install using pip from PyPI:

$ pip install tesults


Installation
------------

Install pytest-tesults using pip from PyPI:

$ pip install pytest-tesults


Usage
-----

Visit https://www.tesults.com/docs?doc=pytest for documentation.


License
-------

Distributed under the terms of the MIT license, "pytest-tesults" is free and open source software


Issues
------

If you encounter any problems, please contact help@tesults.com or visit https://www.tesults.com/contact
